# crc-pulp_file-client
Fetch, Upload, Organize, and Distribute Software Packages

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 20260324.1
- Generator version: 7.10.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import pulpcore.client.pulp_file
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pulpcore.client.pulp_file
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import pulpcore.client.pulp_file
from pulpcore.client.pulp_file.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://env-ephemeral-nwkswa.apps.crc-eph.r9lp.p1.openshiftapps.com
# See configuration.py for a list of all supported configuration parameters.
configuration = pulpcore.client.pulp_file.Configuration(
    host = "https://env-ephemeral-nwkswa.apps.crc-eph.r9lp.p1.openshiftapps.com"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicAuth
configuration = pulpcore.client.pulp_file.Configuration(
    username = os.environ["USERNAME"],
    password = os.environ["PASSWORD"]
)

# Configure API key authorization: cookieAuth
configuration.api_key['cookieAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['cookieAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with pulpcore.client.pulp_file.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = pulpcore.client.pulp_file.AcsFileApi(api_client)
    file_file_alternate_content_source_href = 'file_file_alternate_content_source_href_example' # str | 
    nested_role = pulpcore.client.pulp_file.NestedRole() # NestedRole | 
    x_task_diagnostics = ['x_task_diagnostics_example'] # List[str] | List of profilers to use on tasks. (optional)

    try:
        # Add a role
        api_response = api_instance.add_role(file_file_alternate_content_source_href, nested_role, x_task_diagnostics=x_task_diagnostics)
        print("The response of AcsFileApi->add_role:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AcsFileApi->add_role: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://env-ephemeral-nwkswa.apps.crc-eph.r9lp.p1.openshiftapps.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AcsFileApi* | [**add_role**](docs/AcsFileApi.md#add_role) | **POST** {file_file_alternate_content_source_href}add_role/ | Add a role
*AcsFileApi* | [**create**](docs/AcsFileApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/acs/file/file/ | Create a file alternate content source
*AcsFileApi* | [**delete**](docs/AcsFileApi.md#delete) | **DELETE** {file_file_alternate_content_source_href} | Delete a file alternate content source
*AcsFileApi* | [**list**](docs/AcsFileApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/acs/file/file/ | List file alternate content sources
*AcsFileApi* | [**list_roles**](docs/AcsFileApi.md#list_roles) | **GET** {file_file_alternate_content_source_href}list_roles/ | List roles
*AcsFileApi* | [**my_permissions**](docs/AcsFileApi.md#my_permissions) | **GET** {file_file_alternate_content_source_href}my_permissions/ | List user permissions
*AcsFileApi* | [**partial_update**](docs/AcsFileApi.md#partial_update) | **PATCH** {file_file_alternate_content_source_href} | Update a file alternate content source
*AcsFileApi* | [**read**](docs/AcsFileApi.md#read) | **GET** {file_file_alternate_content_source_href} | Inspect a file alternate content source
*AcsFileApi* | [**refresh**](docs/AcsFileApi.md#refresh) | **POST** {file_file_alternate_content_source_href}refresh/ | Refresh metadata
*AcsFileApi* | [**remove_role**](docs/AcsFileApi.md#remove_role) | **POST** {file_file_alternate_content_source_href}remove_role/ | Remove a role
*AcsFileApi* | [**update**](docs/AcsFileApi.md#update) | **PUT** {file_file_alternate_content_source_href} | Update a file alternate content source
*ContentFilesApi* | [**create**](docs/ContentFilesApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/content/file/files/ | Create a file content
*ContentFilesApi* | [**list**](docs/ContentFilesApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/content/file/files/ | List file contents
*ContentFilesApi* | [**read**](docs/ContentFilesApi.md#read) | **GET** {file_file_content_href} | Inspect a file content
*ContentFilesApi* | [**set_label**](docs/ContentFilesApi.md#set_label) | **POST** {file_file_content_href}set_label/ | Set a label
*ContentFilesApi* | [**unset_label**](docs/ContentFilesApi.md#unset_label) | **POST** {file_file_content_href}unset_label/ | Unset a label
*ContentFilesApi* | [**upload**](docs/ContentFilesApi.md#upload) | **POST** /api/pulp/{pulp_domain}/api/v3/content/file/files/upload/ | Upload a File synchronously.
*DistributionsFileApi* | [**add_role**](docs/DistributionsFileApi.md#add_role) | **POST** {file_file_distribution_href}add_role/ | Add a role
*DistributionsFileApi* | [**create**](docs/DistributionsFileApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/distributions/file/file/ | Create a file distribution
*DistributionsFileApi* | [**delete**](docs/DistributionsFileApi.md#delete) | **DELETE** {file_file_distribution_href} | Delete a file distribution
*DistributionsFileApi* | [**list**](docs/DistributionsFileApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/distributions/file/file/ | List file distributions
*DistributionsFileApi* | [**list_roles**](docs/DistributionsFileApi.md#list_roles) | **GET** {file_file_distribution_href}list_roles/ | List roles
*DistributionsFileApi* | [**my_permissions**](docs/DistributionsFileApi.md#my_permissions) | **GET** {file_file_distribution_href}my_permissions/ | List user permissions
*DistributionsFileApi* | [**partial_update**](docs/DistributionsFileApi.md#partial_update) | **PATCH** {file_file_distribution_href} | Update a file distribution
*DistributionsFileApi* | [**read**](docs/DistributionsFileApi.md#read) | **GET** {file_file_distribution_href} | Inspect a file distribution
*DistributionsFileApi* | [**remove_role**](docs/DistributionsFileApi.md#remove_role) | **POST** {file_file_distribution_href}remove_role/ | Remove a role
*DistributionsFileApi* | [**set_label**](docs/DistributionsFileApi.md#set_label) | **POST** {file_file_distribution_href}set_label/ | Set a label
*DistributionsFileApi* | [**unset_label**](docs/DistributionsFileApi.md#unset_label) | **POST** {file_file_distribution_href}unset_label/ | Unset a label
*DistributionsFileApi* | [**update**](docs/DistributionsFileApi.md#update) | **PUT** {file_file_distribution_href} | Update a file distribution
*PublicationsFileApi* | [**add_role**](docs/PublicationsFileApi.md#add_role) | **POST** {file_file_publication_href}add_role/ | Add a role
*PublicationsFileApi* | [**create**](docs/PublicationsFileApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/publications/file/file/ | Create a file publication
*PublicationsFileApi* | [**delete**](docs/PublicationsFileApi.md#delete) | **DELETE** {file_file_publication_href} | Delete a file publication
*PublicationsFileApi* | [**list**](docs/PublicationsFileApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/publications/file/file/ | List file publications
*PublicationsFileApi* | [**list_roles**](docs/PublicationsFileApi.md#list_roles) | **GET** {file_file_publication_href}list_roles/ | List roles
*PublicationsFileApi* | [**my_permissions**](docs/PublicationsFileApi.md#my_permissions) | **GET** {file_file_publication_href}my_permissions/ | List user permissions
*PublicationsFileApi* | [**read**](docs/PublicationsFileApi.md#read) | **GET** {file_file_publication_href} | Inspect a file publication
*PublicationsFileApi* | [**remove_role**](docs/PublicationsFileApi.md#remove_role) | **POST** {file_file_publication_href}remove_role/ | Remove a role
*RemotesFileApi* | [**add_role**](docs/RemotesFileApi.md#add_role) | **POST** {file_file_remote_href}add_role/ | Add a role
*RemotesFileApi* | [**create**](docs/RemotesFileApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/remotes/file/file/ | Create a file remote
*RemotesFileApi* | [**delete**](docs/RemotesFileApi.md#delete) | **DELETE** {file_file_remote_href} | Delete a file remote
*RemotesFileApi* | [**list**](docs/RemotesFileApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/remotes/file/file/ | List file remotes
*RemotesFileApi* | [**list_roles**](docs/RemotesFileApi.md#list_roles) | **GET** {file_file_remote_href}list_roles/ | List roles
*RemotesFileApi* | [**my_permissions**](docs/RemotesFileApi.md#my_permissions) | **GET** {file_file_remote_href}my_permissions/ | List user permissions
*RemotesFileApi* | [**partial_update**](docs/RemotesFileApi.md#partial_update) | **PATCH** {file_file_remote_href} | Update a file remote
*RemotesFileApi* | [**read**](docs/RemotesFileApi.md#read) | **GET** {file_file_remote_href} | Inspect a file remote
*RemotesFileApi* | [**remove_role**](docs/RemotesFileApi.md#remove_role) | **POST** {file_file_remote_href}remove_role/ | Remove a role
*RemotesFileApi* | [**set_label**](docs/RemotesFileApi.md#set_label) | **POST** {file_file_remote_href}set_label/ | Set a label
*RemotesFileApi* | [**unset_label**](docs/RemotesFileApi.md#unset_label) | **POST** {file_file_remote_href}unset_label/ | Unset a label
*RemotesFileApi* | [**update**](docs/RemotesFileApi.md#update) | **PUT** {file_file_remote_href} | Update a file remote
*RepositoriesFileApi* | [**add_role**](docs/RepositoriesFileApi.md#add_role) | **POST** {file_file_repository_href}add_role/ | Add a role
*RepositoriesFileApi* | [**create**](docs/RepositoriesFileApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/repositories/file/file/ | Create a file repository
*RepositoriesFileApi* | [**delete**](docs/RepositoriesFileApi.md#delete) | **DELETE** {file_file_repository_href} | Delete a file repository
*RepositoriesFileApi* | [**list**](docs/RepositoriesFileApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/repositories/file/file/ | List file repositorys
*RepositoriesFileApi* | [**list_roles**](docs/RepositoriesFileApi.md#list_roles) | **GET** {file_file_repository_href}list_roles/ | List roles
*RepositoriesFileApi* | [**modify**](docs/RepositoriesFileApi.md#modify) | **POST** {file_file_repository_href}modify/ | Modify Repository Content
*RepositoriesFileApi* | [**my_permissions**](docs/RepositoriesFileApi.md#my_permissions) | **GET** {file_file_repository_href}my_permissions/ | List user permissions
*RepositoriesFileApi* | [**partial_update**](docs/RepositoriesFileApi.md#partial_update) | **PATCH** {file_file_repository_href} | Update a file repository
*RepositoriesFileApi* | [**read**](docs/RepositoriesFileApi.md#read) | **GET** {file_file_repository_href} | Inspect a file repository
*RepositoriesFileApi* | [**remove_role**](docs/RepositoriesFileApi.md#remove_role) | **POST** {file_file_repository_href}remove_role/ | Remove a role
*RepositoriesFileApi* | [**set_label**](docs/RepositoriesFileApi.md#set_label) | **POST** {file_file_repository_href}set_label/ | Set a label
*RepositoriesFileApi* | [**sync**](docs/RepositoriesFileApi.md#sync) | **POST** {file_file_repository_href}sync/ | Sync from a remote
*RepositoriesFileApi* | [**unset_label**](docs/RepositoriesFileApi.md#unset_label) | **POST** {file_file_repository_href}unset_label/ | Unset a label
*RepositoriesFileApi* | [**update**](docs/RepositoriesFileApi.md#update) | **PUT** {file_file_repository_href} | Update a file repository
*RepositoriesFileVersionsApi* | [**delete**](docs/RepositoriesFileVersionsApi.md#delete) | **DELETE** {file_file_repository_version_href} | Delete a repository version
*RepositoriesFileVersionsApi* | [**list**](docs/RepositoriesFileVersionsApi.md#list) | **GET** {file_file_repository_href}versions/ | List repository versions
*RepositoriesFileVersionsApi* | [**read**](docs/RepositoriesFileVersionsApi.md#read) | **GET** {file_file_repository_version_href} | Inspect a repository version
*RepositoriesFileVersionsApi* | [**repair**](docs/RepositoriesFileVersionsApi.md#repair) | **POST** {file_file_repository_version_href}repair/ | 


## Documentation For Models

 - [AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [FileContentUploadResponse](docs/FileContentUploadResponse.md)
 - [FileFileAlternateContentSource](docs/FileFileAlternateContentSource.md)
 - [FileFileAlternateContentSourceResponse](docs/FileFileAlternateContentSourceResponse.md)
 - [FileFileContentResponse](docs/FileFileContentResponse.md)
 - [FileFileDistribution](docs/FileFileDistribution.md)
 - [FileFileDistributionResponse](docs/FileFileDistributionResponse.md)
 - [FileFilePublication](docs/FileFilePublication.md)
 - [FileFilePublicationResponse](docs/FileFilePublicationResponse.md)
 - [FileFileRemote](docs/FileFileRemote.md)
 - [FileFileRemoteResponse](docs/FileFileRemoteResponse.md)
 - [FileFileRemoteResponseHiddenFieldsInner](docs/FileFileRemoteResponseHiddenFieldsInner.md)
 - [FileFileRepository](docs/FileFileRepository.md)
 - [FileFileRepositoryResponse](docs/FileFileRepositoryResponse.md)
 - [MyPermissionsResponse](docs/MyPermissionsResponse.md)
 - [NestedRole](docs/NestedRole.md)
 - [NestedRoleResponse](docs/NestedRoleResponse.md)
 - [ObjectRolesResponse](docs/ObjectRolesResponse.md)
 - [PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PaginatedfileFileAlternateContentSourceResponseList](docs/PaginatedfileFileAlternateContentSourceResponseList.md)
 - [PaginatedfileFileContentResponseList](docs/PaginatedfileFileContentResponseList.md)
 - [PaginatedfileFileDistributionResponseList](docs/PaginatedfileFileDistributionResponseList.md)
 - [PaginatedfileFilePublicationResponseList](docs/PaginatedfileFilePublicationResponseList.md)
 - [PaginatedfileFileRemoteResponseList](docs/PaginatedfileFileRemoteResponseList.md)
 - [PaginatedfileFileRepositoryResponseList](docs/PaginatedfileFileRepositoryResponseList.md)
 - [PatchedfileFileAlternateContentSource](docs/PatchedfileFileAlternateContentSource.md)
 - [PatchedfileFileDistribution](docs/PatchedfileFileDistribution.md)
 - [PatchedfileFileRemote](docs/PatchedfileFileRemote.md)
 - [PatchedfileFileRepository](docs/PatchedfileFileRepository.md)
 - [PolicyEnum](docs/PolicyEnum.md)
 - [RemoteNetworkConfig](docs/RemoteNetworkConfig.md)
 - [RemoteNetworkConfigResponse](docs/RemoteNetworkConfigResponse.md)
 - [Repair](docs/Repair.md)
 - [RepositoryAddRemoveContent](docs/RepositoryAddRemoveContent.md)
 - [RepositorySyncURL](docs/RepositorySyncURL.md)
 - [RepositoryVersionResponse](docs/RepositoryVersionResponse.md)
 - [SetLabel](docs/SetLabel.md)
 - [SetLabelResponse](docs/SetLabelResponse.md)
 - [TaskGroupOperationResponse](docs/TaskGroupOperationResponse.md)
 - [UnsetLabel](docs/UnsetLabel.md)
 - [UnsetLabelResponse](docs/UnsetLabelResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="basicAuth"></a>
### basicAuth

- **Type**: HTTP basic authentication

<a id="cookieAuth"></a>
### cookieAuth

- **Type**: API key
- **API key parameter name**: sessionid
- **Location**: 


## Author

pulp-list@redhat.com


